# CinderX

![PyPI - Version](https://img.shields.io/pypi/v/cinderx)

High-performance Python runtime extensions

Note: currently the only way to use Cinder is as an [alternative CPython runtime](https://github.com/facebookincubator/cinder),
which isn't [officially supported](https://github.com/facebookincubator/cinder#is-this-supported).
This extension is a work-in-progress aimed at extracting parts of Cinder as a pip-installable extension.

## License
CinderX is MIT licensed, as found in the LICENSE file.

## Terms of Use
https://opensource.fb.com/legal/terms

## Privacy Policy
https://opensource.fb.com/legal/privacy

##
Copyright © 2025 Meta Platforms, Inc.
